@@ -482,7 +482,7 @@ addons_open_in_editor_clicked_cb (GtkWidget* toolitem,
 
         g_object_get (settings, "text-editor", &text_editor, NULL);
         if (text_editor && *text_editor)
-            sokoke_spawn_program (text_editor, TRUE, element->fullpath, TRUE);
+            sokoke_spawn_program (text_editor, TRUE, element->fullpath, TRUE, FALSE);
         else
         {
             gchar* element_uri = g_filename_to_uri (element->fullpath, NULL, NULL);
@@ -1517,30 +1517,19 @@ addons_add_tab_cb (MidoriBrowser* browser,
         G_CALLBACK (addons_notify_load_status_cb), extension);
 }
 
-static void
-addons_add_tab_foreach_cb (MidoriView*      view,
-                           MidoriBrowser*   browser,
-                           MidoriExtension* extension)
-{
-    addons_add_tab_cb (browser, view, extension);
-}
-
-static void
-addons_deactivate_tabs (MidoriView*      view,
-                        MidoriExtension* extension)
-{
-    GtkWidget* web_view = midori_view_get_web_view (view);
-    g_signal_handlers_disconnect_by_func (
-        web_view, addons_context_ready_cb, extension);
-}
-
 static void
 addons_browser_destroy (MidoriBrowser*   browser,
                         MidoriExtension* extension)
 {
     GtkWidget* scripts, *styles;
-
-    midori_browser_foreach (browser, (GtkCallback)addons_deactivate_tabs, extension);
+    GList* tabs = midori_browser_get_tabs (browser);
+    for (; tabs; tabs = g_list_next (tabs))
+    {
+        GtkWidget* web_view = midori_view_get_web_view (tabs->data);
+        g_signal_handlers_disconnect_by_func (
+            web_view, addons_context_ready_cb, extension);
+    }
+    g_list_free (tabs);
     g_signal_handlers_disconnect_by_func (browser, addons_add_tab_cb, extension);
 
     scripts = (GtkWidget*)g_object_get_data (G_OBJECT (browser), "scripts-addons");
@@ -1620,9 +1609,10 @@ addons_app_add_browser_cb (MidoriApp*       app,
 {
     GtkWidget* panel;
     GtkWidget* scripts, *styles;
-
-    midori_browser_foreach (browser,
-          (GtkCallback)addons_add_tab_foreach_cb, extension);
+    GList* tabs = midori_browser_get_tabs (browser);
+    for (; tabs; tabs = g_list_next (tabs))
+        addons_add_tab_cb (browser, tabs->data, extension);
+    g_list_free (tabs);
     g_signal_connect (browser, "add-tab",
         G_CALLBACK (addons_add_tab_cb), extension);
     panel = katze_object_get_object (browser, "panel");
@@ -1857,7 +1847,6 @@ addons_activate_cb (MidoriExtension* extension,
         G_CALLBACK (addons_deactivate_cb), app);
 }
 
-#ifdef G_ENABLE_DEBUG
 static void
 test_addons_simple_regexp (void)
 {
@@ -1896,7 +1885,6 @@ extension_test (void)
 {
     g_test_add_func ("/extensions/addons/simple_regexp", test_addons_simple_regexp);
 }
-#endif
 
 MidoriExtension*
 extension_init (void)
