@@ -24,7 +24,6 @@ struct _FeedPanel
     GtkWidget* treeview;
     GtkWidget* webview;
     GtkWidget* delete;
-    GdkPixbuf* pixbuf;
 };
 
 struct _FeedPanelClass
@@ -82,22 +81,17 @@ feed_panel_treeview_render_icon_cb (GtkTreeViewColumn* column,
     else
         pitem = item;
 
-    uri = katze_item_get_uri (pitem);
-    if (uri)
+    if ((uri = katze_item_get_uri (pitem)))
     {
-        pixbuf = katze_load_cached_icon (uri, NULL);
-        if (!pixbuf)
-            pixbuf = panel->pixbuf;
+        if (!(pixbuf = midori_paths_get_icon (uri, NULL)))
+            pixbuf = gtk_widget_render_icon (panel->treeview, STOCK_NEWS_FEED, GTK_ICON_SIZE_MENU, NULL);
     }
     else
-    {
-        pixbuf = gtk_widget_render_icon (panel->treeview,
-                     GTK_STOCK_DIALOG_ERROR, GTK_ICON_SIZE_MENU, NULL);
-    }
+        pixbuf = gtk_widget_render_icon (panel->treeview, GTK_STOCK_DIALOG_ERROR, GTK_ICON_SIZE_MENU, NULL);
 
     g_object_set (renderer, "pixbuf", pixbuf, NULL);
 
-    if (pixbuf != panel->pixbuf)
+    if (pixbuf)
         g_object_unref (pixbuf);
 }
 
@@ -326,14 +320,11 @@ feed_panel_row_activated_cb (GtkTreeView*       treeview,
         uri = katze_item_get_uri (item);
         if (uri && *uri)
         {
-            MidoriWebSettings* settings;
-            MidoriBrowser* browser;
-            gint n;
-            browser = midori_browser_get_for_widget (GTK_WIDGET (panel));
-            n = midori_browser_add_item (browser, item);
-            settings = midori_browser_get_settings (browser);
+            MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (panel));
+            GtkWidget* view = midori_browser_add_item (browser, item);
+            MidoriWebSettings* settings = midori_browser_get_settings (browser);
             if (!katze_object_get_boolean (settings, "open-tabs-in-the-background"))
-                midori_browser_set_current_page (browser, n);
+                midori_browser_set_current_tab (browser, view);
         }
         g_object_unref (item);
     }
@@ -358,45 +349,42 @@ feed_panel_cursor_or_row_changed_cb (GtkTreeView* treeview,
 
         if (KATZE_IS_ARRAY (item))
         {
-            gint64 date;
-
             text = NULL;
             if (!uri)
                 text = g_strdup (katze_item_get_text (KATZE_ITEM (item)));
             else
             {
-                KatzeItem* parent;
-                const gchar* puri;
-
-                parent = katze_item_get_parent (item);
+                KatzeItem* parent = katze_item_get_parent (item);
+                gint64 added = katze_item_get_added (item);
                 g_assert (KATZE_IS_ARRAY (parent));
-                date = katze_item_get_added (item);
-                puri = katze_item_get_uri (parent);
-                if (date)
+                if (added)
                 {
-                    time_t date_t;
-                    const struct tm* tm;
-                    static gchar date_format[512];
-                    gchar* last_updated;
+                    #if GLIB_CHECK_VERSION (2, 26, 0)
+                    GDateTime* date = g_date_time_new_from_unix_local (added);
+                    gchar* pretty = g_date_time_format (date, "%c");
+                    g_date_time_unref (date);
+                    #else
+                    static gchar date_fmt[512];
+                    const struct tm *tm = localtime (&added);
+                    /* Some GCC versions falsely complain about "%c" */
+                    strftime (date_fmt, sizeof (date_fmt), "%c", tm);
+                    gchar* pretty = g_strdup (date_fmt);
+                    #endif
 
-                    date_t = (time_t)date;
-                    tm = localtime (&date_t);
-                    /* Some gcc versions complain about "%c" for no reason */
-                    strftime (date_format, sizeof (date_format), "%c", tm);
     /* i18n: The local date a feed was last updated */
-                    last_updated = g_strdup_printf (C_("Feed", "Last updated: %s."),
-                                                    date_format);
+                    gchar* last_updated = g_strdup_printf (C_("Feed", "Last updated: %s."), pretty);
                     text = g_strdup_printf (
                             "<html><head><title>feed</title></head>"
                             "<body><h3>%s</h3><p />%s</body></html>",
-                            puri, last_updated);
+                            parent->uri, last_updated);
+                    g_free (pretty);
                     g_free (last_updated);
                 }
                 else
                 {
                     text = g_strdup_printf (
                             "<html><head><title>feed</title></head>"
-                            "<body><h3>%s</h3></body></html>", puri);
+                            "<body><h3>%s</h3></body></html>", parent->uri);
                 }
             }
             webkit_web_view_load_html_string (
@@ -468,14 +456,11 @@ feed_panel_open_in_tab_activate_cb (GtkWidget* menuitem,
 
     if ((uri = katze_item_get_uri (item)) && *uri)
     {
-        MidoriWebSettings* settings;
-        MidoriBrowser* browser;
-
-        browser = midori_browser_get_for_widget (GTK_WIDGET (panel));
-        n = midori_browser_add_item (browser, item);
-        settings = midori_browser_get_settings (browser);
+        MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (panel));
+        GtkWidget* view = midori_browser_add_item (browser, item);
+        MidoriWebSettings* settings = midori_browser_get_settings (browser);
         if (!katze_object_get_boolean (settings, "open-tabs-in-the-background"))
-            midori_browser_set_current_page (browser, n);
+            midori_browser_set_current_tab (browser, view);
     }
 }
 
@@ -563,16 +548,11 @@ feed_panel_button_release_event_cb (GtkWidget*      widget,
 
             if (uri && *uri)
             {
-                MidoriWebSettings* settings;
-                MidoriBrowser* browser;
-                gint n;
-
-                browser = midori_browser_get_for_widget (GTK_WIDGET (panel));
-                n = midori_browser_add_item (browser, item);
-
-                settings = midori_browser_get_settings (browser);
+                MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (panel));
+                GtkWidget* view = midori_browser_add_item (browser, item);
+                MidoriWebSettings* settings = midori_browser_get_settings (browser);
                 if (!katze_object_get_boolean (settings, "open-tabs-in-the-background"))
-                    midori_browser_set_current_page (browser, n);
+                    midori_browser_set_current_tab (browser, view);
             }
         }
         else
@@ -631,14 +611,10 @@ webview_navigation_request_cb (WebKitWebView*             web_view,
     if (webkit_web_navigation_action_get_reason (navigation_action) ==
         WEBKIT_WEB_NAVIGATION_REASON_LINK_CLICKED)
     {
-        MidoriBrowser* browser;
-        const gchar* uri;
-        gint n;
-
-        browser = midori_browser_get_for_widget (GTK_WIDGET (panel));
-        uri = webkit_network_request_get_uri (request);
-        n = midori_browser_add_uri (browser, uri);
-        midori_browser_set_current_page (browser, n);
+        MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (panel));
+        const gchar* uri = webkit_network_request_get_uri (request);
+        GtkWidget* view = midori_browser_add_uri (browser, uri);
+        midori_browser_set_current_tab (browser, view);
         webkit_web_policy_decision_ignore (policy_decision);
 
         return TRUE;
@@ -730,8 +706,6 @@ static void
 feed_panel_finalize (GObject* object)
 {
     FeedPanel* panel = FEED_PANEL (object);
-
-    g_object_unref (panel->pixbuf);
 }
 
 static void
@@ -872,13 +846,10 @@ feed_panel_init (FeedPanel* panel)
 
     paned = gtk_vpaned_new ();
     gtk_paned_pack1 (GTK_PANED (paned), treewin, TRUE, FALSE);
-    gtk_paned_pack2 (GTK_PANED (paned), webview, TRUE, FALSE);
+    gtk_paned_pack2 (GTK_PANED (paned), webview, TRUE, TRUE);
     gtk_box_pack_start (GTK_BOX (panel), paned, TRUE, TRUE, 0);
     gtk_widget_show (webview);
     gtk_widget_show (paned);
-
-    panel->pixbuf = gtk_widget_render_icon (treeview,
-                     STOCK_NEWS_FEED, GTK_ICON_SIZE_MENU, NULL);
 }
 
 GtkWidget*
