@@ -172,7 +172,7 @@ statusbar_features_property_proxy (MidoriWebSettings* settings,
         if (!midori_web_settings_has_plugin_support ())
             gtk_widget_hide (button);
         g_object_set_data (G_OBJECT (button), "feature-label", _("Netscape plugins"));
-        image = gtk_image_new_from_stock (STOCK_PLUGINS, GTK_ICON_SIZE_MENU);
+        image = gtk_image_new_from_stock (MIDORI_STOCK_PLUGINS, GTK_ICON_SIZE_MENU);
         gtk_button_set_image (GTK_BUTTON (button), image);
         gtk_widget_set_tooltip_text (button, _("Enable Netscape plugins"));
         statusbar_features_toolbar_notify_toolbar_style_cb (toolbar, NULL, button);
