@@ -39,12 +39,11 @@ tab_panel_browser_notify_tab_cb (MidoriBrowser* browser,
                                  GtkTreeView*   treeview);
 static void
 tab_panel_browser_move_tab_cb (MidoriBrowser* browser,
-                               GtkNotebook*   notebook,
+                               GtkWidget*     notebook,
                                gint           cur_pos,
                                gint           new_pos,
                                gpointer       user_data);
 
-
 static void
 tab_panel_view_notify_minimized_cb (GtkWidget*       view,
                                     GParamSpec*      pspec,
@@ -104,13 +103,19 @@ tab_panel_deactivate_cb (MidoriExtension* extension,
                          GtkWidget*       treeview)
 {
     MidoriApp* app = midori_extension_get_app (extension);
-    GtkTreeModel* model;
-    MidoriBrowser* browser;
-
-    browser = midori_browser_get_for_widget (treeview);
-    g_object_set (browser, "show-tabs", TRUE, NULL);
-    model = tab_panel_get_model_for_browser (browser);
-    g_object_unref (model);
+    MidoriBrowser* browser = midori_browser_get_for_widget (treeview);
+    GtkTreeModel* model = tab_panel_get_model_for_browser (browser);
+    GList* tabs = midori_browser_get_tabs (browser);
+    for (; tabs; tabs = g_list_next (tabs))
+    {
+        g_signal_handlers_disconnect_by_func (
+            tabs->data, tab_panel_view_notify_minimized_cb, extension);
+        g_signal_handlers_disconnect_by_func (
+            tabs->data, tab_panel_view_notify_icon_cb, extension);
+        g_signal_handlers_disconnect_by_func (
+            tabs->data, tab_panel_view_notify_title_cb, extension);
+    }
+    g_list_free (tabs);
 
     g_signal_handlers_disconnect_by_func (
         extension, tab_panel_deactivate_cb, treeview);
@@ -124,16 +129,14 @@ tab_panel_deactivate_cb (MidoriExtension* extension,
         browser, tab_panel_browser_notify_tab_cb, treeview);
     g_signal_handlers_disconnect_by_func (
         browser, tab_panel_settings_notify_cb, model);
-    g_signal_handlers_disconnect_by_func (
-        browser, tab_panel_view_notify_minimized_cb, extension);
-    g_signal_handlers_disconnect_by_func (
-        browser, tab_panel_view_notify_icon_cb, extension);
-    g_signal_handlers_disconnect_by_func (
-        browser, tab_panel_view_notify_title_cb, extension);
     g_signal_handlers_disconnect_by_func (
         browser, tab_panel_browser_move_tab_cb, NULL);
 
     gtk_widget_destroy (treeview);
+    g_object_unref (model);
+    g_object_set_data (G_OBJECT (browser), "tab-panel-ext-model", NULL);
+    g_object_set (browser, "show-tabs", TRUE, NULL);
+
 }
 
 static void
@@ -229,12 +232,12 @@ midori_extension_button_release_event_cb (GtkWidget*       widget,
             if (gtk_tree_view_get_path_at_pos (GTK_TREE_VIEW (widget),
                 event->x, event->y, NULL, &column, NULL, NULL)
                 && column == gtk_tree_view_get_column (GTK_TREE_VIEW (widget), 1))
-                midori_browser_remove_tab (browser, view);
+                midori_browser_close_tab (browser, view);
             else
                 midori_browser_set_current_tab (browser, view);
         }
         else if (event->button == 2)
-            midori_browser_remove_tab (midori_browser_get_for_widget (widget), view);
+            midori_browser_close_tab (midori_browser_get_for_widget (widget), view);
         else
             tab_panel_popup (widget, event, view);
 
@@ -467,14 +470,6 @@ tab_panel_browser_add_tab_cb (MidoriBrowser*   browser,
     }
 }
 
-static void
-tab_panel_browser_foreach_cb (GtkWidget*       view,
-                              MidoriExtension* extension)
-{
-    tab_panel_browser_add_tab_cb (midori_browser_get_for_widget (view),
-                                  view, extension);
-}
-
 static void
 tab_panel_browser_remove_tab_cb (MidoriBrowser*   browser,
                                  GtkWidget*       view,
@@ -591,8 +586,10 @@ tab_panel_app_add_browser_cb (MidoriApp*       app,
         midori_panel_set_current_page (MIDORI_PANEL (panel), i);
     g_object_unref (panel);
 
-    midori_browser_foreach (browser,
-        (GtkCallback)tab_panel_browser_foreach_cb, treeview);
+    GList* tabs = midori_browser_get_tabs (browser);
+    for (; tabs; tabs = g_list_next (tabs))
+        tab_panel_browser_add_tab_cb (browser, tabs->data, extension);
+    g_list_free (tabs);
 
     g_signal_connect_after (browser, "add-tab",
         G_CALLBACK (tab_panel_browser_add_tab_cb), extension);
@@ -623,7 +620,7 @@ tab_panel_activate_cb (MidoriExtension* extension,
 
 static void
 tab_panel_browser_move_tab_cb (MidoriBrowser* browser,
-                               GtkNotebook*   notebook,
+                               GtkWidget*     notebook,
                                gint           cur_pos,
                                gint           new_pos,
                                gpointer       user_data)
@@ -632,7 +629,7 @@ tab_panel_browser_move_tab_cb (MidoriBrowser* browser,
     gint last_page;
     GtkTreeModel *model;
 
-    last_page = gtk_notebook_get_n_pages (notebook) - 1;
+    last_page = midori_browser_get_n_pages (browser) - 1;
     model = tab_panel_get_model_for_browser (browser);
 
     gtk_tree_model_iter_nth_child (model, &cur, NULL, cur_pos);
