@@ -14,6 +14,7 @@
 #endif
 
 #include "katze-http-cookies.h"
+#include "midori/midori-core.h"
 
 #include <stdlib.h>
 #ifdef HAVE_UNISTD_H
@@ -267,8 +268,8 @@ katze_http_cookies_jar_changed_cb (SoupCookieJar*    jar,
         http_cookies->counter++;
 
     if (!http_cookies->timeout && (old_cookie || new_cookie->expires))
-        http_cookies->timeout = g_timeout_add_seconds (5,
-            (GSourceFunc)katze_http_cookies_update_jar, http_cookies);
+        http_cookies->timeout = midori_timeout_add_seconds (
+            5, (GSourceFunc)katze_http_cookies_update_jar, http_cookies, NULL);
 }
 
 static void
