@@ -729,7 +729,12 @@ string_append_item (GString*   string,
         g_string_append (string, "<bookmark href=\"");
         string_append_escaped (string, katze_item_get_uri (item));
         g_string_append (string, "\">\n");
-        string_append_xml_element (string, "title", katze_item_get_name (item));
+        /* Strip LRE leading character */
+        if (item->name != NULL && g_str_has_prefix (item->name, "‪"))
+            string_append_xml_element (string, "title",
+                g_utf8_next_char (strstr (item->name, "‪")));
+        else
+            string_append_xml_element (string, "title", item->name);
         string_append_xml_element (string, "desc", katze_item_get_text (item));
         g_string_append (string, metadata);
         g_string_append (string, "</bookmark>\n");
@@ -901,7 +906,7 @@ midori_array_to_file_format (KatzeArray*  array,
                              GError**     error)
 {
     gchar* data;
-    FILE* fp;
+    gboolean success;
 
     if (!g_strcmp0 (format, "xbel"))
         data = katze_array_to_xbel (array, error);
@@ -909,16 +914,10 @@ midori_array_to_file_format (KatzeArray*  array,
         data = katze_array_to_netscape_html (array, error);
     else
         return FALSE;
-    if (!(fp = fopen (filename, "w")))
-    {
-        *error = g_error_new_literal (G_FILE_ERROR, G_FILE_ERROR_ACCES,
-                                      _("Writing failed."));
-        return FALSE;
-    }
-    fputs (data, fp);
-    fclose (fp);
+
+    success = g_file_set_contents (filename, data, -1, error);
     g_free (data);
-    return TRUE;
+    return success;
 }
 
 /**
@@ -975,7 +974,7 @@ katze_item_set_value_from_column (sqlite3_stmt* stmt,
         title = sqlite3_column_text (stmt, column);
         item->name = g_strdup ((gchar*)title);
     }
-    else if (g_str_equal (name, "date"))
+    else if (g_str_equal (name, "date") || g_str_equal (name, "created"))
     {
         gint date;
         date = sqlite3_column_int64 (stmt, column);
@@ -984,6 +983,7 @@ katze_item_set_value_from_column (sqlite3_stmt* stmt,
     else if (g_str_equal (name, "day") || g_str_equal (name, "app")
           || g_str_equal (name, "toolbar") || g_str_equal (name, "id")
           || g_str_equal (name, "parentid") || g_str_equal (name, "seq")
+          || g_str_equal (name, "last_visit") || g_str_equal (name, "visit_count")
           || g_str_equal (name, "pos_panel") || g_str_equal (name, "pos_bar"))
     {
         gint value;
@@ -996,14 +996,14 @@ katze_item_set_value_from_column (sqlite3_stmt* stmt,
         text = sqlite3_column_text (stmt, column);
         item->text =  g_strdup ((gchar*)text);
     }
-    else if (g_str_equal (name, "sql"))
+    else if (g_str_equal (name, "nick"))
     {
         const unsigned char* sql;
         sql = sqlite3_column_text (stmt, column);
         katze_item_set_meta_string (item, name, (gchar*)sql);
     }
     else
-        g_warn_if_reached ();
+        g_critical ("%s: Unexpected column '%s'", G_STRFUNC, name);
 }
 
 /**
@@ -1100,8 +1100,7 @@ midori_array_query_recursive (KatzeArray*  bookmarks,
     g_return_val_if_fail (fields, NULL);
     g_return_val_if_fail (condition, NULL);
     db = g_object_get_data (G_OBJECT (bookmarks), "db");
-    if (db == NULL)
-        return NULL;
+    g_return_val_if_fail (db != NULL, NULL);
 
     sqlcmd = g_strdup_printf ("SELECT %s FROM bookmarks WHERE %s "
                               "ORDER BY (uri='') ASC, title DESC", fields, condition);
