@@ -12,8 +12,6 @@
 #ifndef __MIDORI_BROWSER_H__
 #define __MIDORI_BROWSER_H__
 
-#include <webkit/webkit.h>
-
 #include <katze/katze.h>
 #include "midori-view.h"
 
@@ -42,7 +40,11 @@ struct _MidoriBrowserClass
     /* Signals */
     void
     (*window_object_cleared)   (MidoriBrowser*       browser,
+#ifndef HAVE_WEBKIT2
                                 WebKitWebFrame*      web_frame,
+#else
+                                void*                web_frame,
+#endif
                                 JSContextRef*        context,
                                 JSObjectRef*         window_object);
     void
@@ -74,7 +76,7 @@ midori_browser_get_type               (void) G_GNUC_CONST;
 MidoriBrowser*
 midori_browser_new                    (void);
 
-gint
+void
 midori_browser_add_tab                (MidoriBrowser*     browser,
                                        GtkWidget*         widget);
 
@@ -82,11 +84,11 @@ void
 midori_browser_close_tab              (MidoriBrowser*     browser,
                                        GtkWidget*         widget);
 
-gint
+GtkWidget*
 midori_browser_add_item               (MidoriBrowser*     browser,
                                        KatzeItem*         item);
 
-gint
+GtkWidget*
 midori_browser_add_uri                (MidoriBrowser*     browser,
                                        const gchar*       uri);
 
@@ -120,6 +122,11 @@ midori_browser_get_current_uri        (MidoriBrowser*     browser);
 void
 midori_browser_set_current_page_smartly (MidoriBrowser* browser,
                                          gint           n);
+
+void
+midori_browser_set_current_tab_smartly (MidoriBrowser* browser,
+                                        GtkWidget*     view);
+
 void
 midori_browser_set_current_page       (MidoriBrowser*     browser,
                                        gint               n);
