@@ -1380,6 +1380,7 @@ midori_location_action_show_page_info (GtkWidget* widget,
                                        GtkBox*    box,
                                        GtkWidget* dialog)
 {
+#ifndef HAVE_WEBKIT2
     MidoriBrowser* browser = midori_browser_get_for_widget (widget);
     MidoriView* view = MIDORI_VIEW (midori_browser_get_current_tab (browser));
     WebKitWebView* web_view = WEBKIT_WEB_VIEW (midori_view_get_web_view (view));
@@ -1437,17 +1438,7 @@ midori_location_action_show_page_info (GtkWidget* widget,
     #endif
 
     g_object_unref (tls_cert);
-}
 #endif
-
-#ifndef HAVE_GRANITE
-static gboolean
-midori_location_action_dialog_focus_out_cb (GtkWidget* dialog,
-                                            GdkEvent*  event,
-                                            gpointer   user_data)
-{
-    gtk_widget_destroy (dialog);
-    return TRUE;
 }
 #endif
 
@@ -1493,10 +1484,6 @@ midori_location_action_icon_released_cb (GtkWidget*           widget,
         #else
         dialog = gtk_dialog_new_with_buttons (title, GTK_WINDOW (gtk_widget_get_toplevel (widget)),
             GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_NO_SEPARATOR, NULL, NULL);
-        /* FIXME: check focus-in on the transient-for window instead of
-                  focus-out-event */
-        g_signal_connect (dialog, "focus-out-event",
-            G_CALLBACK (midori_location_action_dialog_focus_out_cb), NULL);
         content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
         #endif
         hbox = gtk_hbox_new (FALSE, 0);
