@@ -13,6 +13,8 @@
 
 #include "midori-app.h"
 #include "midori-core.h"
+#include "midori-extension.h"
+#include "panels/midori-extensions.h"
 #include "midori-platform.h"
 
 #include <string.h>
@@ -180,7 +182,6 @@ midori_preferences_homepage_current_clicked_cb (GtkWidget*         button,
     }
 }
 
-#if !HAVE_HILDON
 static void
 midori_preferences_notify_proxy_type_cb (MidoriWebSettings* settings,
                                          GParamSpec*        pspec,
@@ -190,7 +191,6 @@ midori_preferences_notify_proxy_type_cb (MidoriWebSettings* settings,
 
     gtk_widget_set_sensitive (entry, proxy_type == MIDORI_PROXY_HTTP);
 }
-#endif
 
 #if HAVE_OSX
 static void
@@ -325,7 +325,6 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     /* Page "Appearance" */
     PAGE_NEW (GTK_STOCK_SELECT_FONT, _("Fonts"));
     FRAME_NEW (NULL);
-    #if !HAVE_HILDON
     label = gtk_label_new (_("Proportional Font Family"));
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
     INDENTED_ADD (label);
@@ -352,7 +351,6 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     SPANNED_ADD (entry);
     button = katze_property_proxy (settings, "enforce-font-family", NULL);
     INDENTED_ADD (button);
-    #endif
     label = gtk_label_new (_("Preferred Encoding"));
     gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
     INDENTED_ADD (label);
@@ -362,7 +360,6 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     /* Page "Behavior" */
     PAGE_NEW (GTK_STOCK_SELECT_COLOR, _("Behavior"));
     FRAME_NEW (NULL);
-    #if !HAVE_HILDON
     button = katze_property_proxy (settings, "auto-load-images", NULL);
     gtk_button_set_label (GTK_BUTTON (button), _("Load images automatically"));
     INDENTED_ADD (button);
@@ -383,11 +380,15 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     button = katze_property_proxy (settings, "enable-scripts", NULL);
     gtk_button_set_label (GTK_BUTTON (button), _("Enable scripts"));
     INDENTED_ADD (button);
+    #if WEBKIT_CHECK_VERSION (1, 3, 8)
+    button = katze_property_proxy (settings, "enable-webgl", NULL);
+    gtk_button_set_label (GTK_BUTTON (button), _("Enable WebGL support"));
+    #else
     button = katze_property_proxy (settings, "enable-plugins", NULL);
     gtk_button_set_label (GTK_BUTTON (button), _("Enable Netscape plugins"));
     gtk_widget_set_sensitive (button, midori_web_settings_has_plugin_support ());
-    SPANNED_ADD (button);
     #endif
+    SPANNED_ADD (button);
     button = katze_property_proxy (settings, "zoom-text-and-images", NULL);
     gtk_button_set_label (GTK_BUTTON (button), _("Zoom Text and Images"));
     INDENTED_ADD (button);
@@ -395,30 +396,14 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
     gtk_button_set_label (GTK_BUTTON (button), _("Allow scripts to open popups"));
     gtk_widget_set_tooltip_text (button, _("Whether scripts are allowed to open popup windows automatically"));
     SPANNED_ADD (button);
-    if (katze_widget_has_touchscreen_mode (parent ?
-        GTK_WIDGET (parent) : GTK_WIDGET (preferences)))
-    {
-        button = katze_property_proxy (settings, "kinetic-scrolling", NULL);
-        gtk_button_set_label (GTK_BUTTON (button), _("Kinetic scrolling"));
-        gtk_widget_set_tooltip_text (button, _("Whether scrolling should kinetically move according to speed"));
-    }
-    else
-    {
-        button = katze_property_proxy (settings, "middle-click-opens-selection", NULL);
-        gtk_button_set_label (GTK_BUTTON (button), _("Middle click opens Selection"));
-        gtk_widget_set_tooltip_text (button, _("Load an address from the selection via middle click"));
-    }
+    button = katze_property_proxy (settings, "middle-click-opens-selection", NULL);
+    gtk_button_set_label (GTK_BUTTON (button), _("Middle click opens Selection"));
+    gtk_widget_set_tooltip_text (button, _("Load an address from the selection via middle click"));
     INDENTED_ADD (button);
-    if (katze_object_has_property (settings, "enable-webgl"))
-    {
-        button = katze_property_proxy (settings, "enable-webgl", NULL);
-        gtk_button_set_label (GTK_BUTTON (button), _("Enable WebGL support"));
-        SPANNED_ADD (button);
-    }
     #ifndef G_OS_WIN32
     button = katze_property_proxy (settings, "flash-window-on-new-bg-tabs", NULL);
     gtk_button_set_label (GTK_BUTTON (button), _("Flash window on background tabs"));
-    INDENTED_ADD (button);
+    SPANNED_ADD (button);
     #endif
 
     FRAME_NEW (NULL);
@@ -436,7 +421,6 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
 
     /* Page "Interface" */
     PAGE_NEW (GTK_STOCK_CONVERT, _("Browsing"));
-    #if !HAVE_HILDON
     if (!g_getenv ("DESKTOP_SESSION"))
     {
         FRAME_NEW (NULL);
@@ -444,7 +428,6 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
         button = katze_property_proxy (settings, "toolbar-style", NULL);
         SPANNED_ADD (button);
     }
-    #endif
     FRAME_NEW (NULL);
     label = katze_property_label (settings, "open-new-pages-in");
     INDENTED_ADD (label);
@@ -503,6 +486,7 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
         G_CALLBACK (midori_preferences_notify_proxy_type_cb), entry);
     midori_preferences_notify_proxy_type_cb (settings, NULL, entry);
     #if WEBKIT_CHECK_VERSION (1, 3, 11)
+#ifndef HAVE_WEBKIT2
     if (soup_session_get_feature (webkit_get_default_session (), SOUP_TYPE_CACHE))
     {
         label = gtk_label_new (_("Web Cache"));
@@ -515,9 +499,101 @@ midori_preferences_set_settings (MidoriPreferences* preferences,
         gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
         SPANNED_ADD (label);
     }
+#endif
     #endif
     label = katze_property_label (settings, "identify-as");
     INDENTED_ADD (label);
     button = katze_property_proxy (settings, "identify-as", "custom-user-agent");
     SPANNED_ADD (button);
 }
+
+void
+midori_preferences_add_privacy_category (KatzePreferences*  preferences,
+                                         MidoriWebSettings* settings)
+{
+    GtkWidget* button;
+    GtkWidget* label;
+    gchar* markup;
+
+    katze_preferences_add_category (preferences, _("Privacy"), GTK_STOCK_INDEX);
+    katze_preferences_add_group (preferences, NULL);
+    button = gtk_label_new (_("Delete old Cookies after:"));
+    gtk_misc_set_alignment (GTK_MISC (button), 0.0, 0.5);
+    gtk_widget_set_tooltip_text (button, _("The maximum number of days to save cookies for"));
+    katze_preferences_add_widget (preferences, button, "indented");
+    button = katze_property_proxy (settings, "maximum-cookie-age", "days");
+    gtk_widget_set_tooltip_text (button, _("The maximum number of days to save cookies for"));
+    katze_preferences_add_widget (preferences, button, "spanned");
+    #ifdef HAVE_LIBSOUP_2_29_91
+    button = katze_property_proxy (settings, "first-party-cookies-only", NULL);
+    gtk_button_set_label (GTK_BUTTON (button), _("Only accept Cookies from sites you visit"));
+    gtk_widget_set_tooltip_text (button, _("Block cookies sent by third-party websites"));
+    katze_preferences_add_widget (preferences, button, "filled");
+    #endif
+
+    markup = g_strdup_printf ("<span size=\"smaller\">%s</span>",
+        _("Cookies store login data, saved games, "
+          "or user profiles for advertisement purposes."));
+    label = gtk_label_new (NULL);
+    gtk_label_set_markup (GTK_LABEL (label), markup);
+    g_free (markup);
+    katze_preferences_add_widget (preferences, label, "filled");
+    button = katze_property_proxy (settings, "enable-offline-web-application-cache", NULL);
+    gtk_button_set_label (GTK_BUTTON (button), _("Enable offline web application cache"));
+    katze_preferences_add_widget (preferences, button, "indented");
+    button = katze_property_proxy (settings, "enable-html5-local-storage", NULL);
+    gtk_button_set_label (GTK_BUTTON (button), _("Enable HTML5 local storage support"));
+    katze_preferences_add_widget (preferences, button, "spanned");
+    button = katze_property_proxy (settings, "strip-referer", NULL);
+    /* i18n: Reworded: Shorten details propagated when going to another page */
+    gtk_button_set_label (GTK_BUTTON (button), _("Strip referrer details sent to websites"));
+    /* i18n: Referer here is not a typo but a technical term */
+    gtk_widget_set_tooltip_text (button, _("Whether the \"Referer\" header should be shortened to the hostname"));
+    katze_preferences_add_widget (preferences, button, "indented");
+    katze_preferences_add_widget (preferences, gtk_label_new (NULL), "indented");
+    button = gtk_label_new (_("Delete pages from history after:"));
+    gtk_misc_set_alignment (GTK_MISC (button), 0.0, 0.5);
+    gtk_widget_set_tooltip_text (button, _("The maximum number of days to save the history for"));
+    katze_preferences_add_widget (preferences, button, "indented");
+    button = katze_property_proxy (settings, "maximum-history-age", "days");
+    gtk_widget_set_tooltip_text (button, _("The maximum number of days to save the history for"));
+    katze_preferences_add_widget (preferences, button, "spanned");
+}
+
+void
+midori_preferences_add_extension_category (KatzePreferences*  preferences,
+                                           MidoriApp*         app)
+{
+    KatzeArray* array;
+    gchar* extension_path;
+    GtkWidget* scrolled;
+    GtkWidget* addon;
+    GList* children;
+    GtkWidget* page;
+
+    array = katze_object_get_object (app, "extensions");
+
+    midori_extension_load_from_folder (app, NULL, FALSE);
+    /* Reset frozen list: allow active extensions to be saved */
+    g_object_set_data (G_OBJECT (app), "extensions", NULL);
+
+    /* Hide if there are no extensions at all */
+    if (!katze_array_get_nth_item (array, 0))
+    {
+        g_object_unref (array);
+        return;
+    }
+    g_object_unref (array);
+
+    scrolled = gtk_scrolled_window_new (NULL, NULL);
+    /* For lack of a better way of keeping descriptions visible */
+    g_object_set (scrolled, "visible", TRUE, "hscrollbar-policy", GTK_POLICY_NEVER, NULL);
+    addon = g_object_new (MIDORI_TYPE_EXTENSIONS, "app", app, NULL);
+    children = gtk_container_get_children (GTK_CONTAINER (addon));
+    gtk_widget_reparent (g_list_nth_data (children, 0), scrolled);
+    g_list_free (children);
+    page = katze_preferences_add_category (preferences,
+                                           _("Extensions"), STOCK_EXTENSION);
+    gtk_box_pack_start (GTK_BOX (page), scrolled, TRUE, TRUE, 4);
+}
+
