@@ -13,6 +13,7 @@
 #define __MIDORI_VIEW_H__
 
 #include "midori-websettings.h"
+#include "midori-core.h"
 
 #include <katze/katze.h>
 
@@ -22,41 +23,16 @@
 
 G_BEGIN_DECLS
 
-#define MIDORI_LOAD_PROVISIONAL WEBKIT_LOAD_PROVISIONAL
-#define MIDORI_LOAD_COMMITTED WEBKIT_LOAD_COMMITTED
-#define MIDORI_LOAD_FINISHED WEBKIT_LOAD_FINISHED
-#define MidoriLoadStatus WebKitLoadStatus
-#define MIDORI_TYPE_LOAD_STATUS WEBKIT_TYPE_LOAD_STATUS
-
 typedef enum
 {
-    MIDORI_NEW_VIEW_TAB,
-    MIDORI_NEW_VIEW_BACKGROUND,
-    MIDORI_NEW_VIEW_WINDOW
-} MidoriNewView;
-
-GType
-midori_new_view_get_type (void) G_GNUC_CONST;
-
-#define MIDORI_TYPE_NEW_VIEW \
-    (midori_new_view_get_type ())
+    MIDORI_DELAY_UNDELAYED = -1, /* The view is in a regular undelayed state */
+    MIDORI_DELAY_DELAYED = 1, /* The view is delayed but has not displayed any indication of such */
+    MIDORI_DELAY_PENDING_UNDELAY = -2 /* The view is delayed and showing a message asking to be undelayed */
+} MidoriDelay;
 
 #define MIDORI_TYPE_VIEW \
     (midori_view_get_type ())
 
-typedef enum
-{
-    MIDORI_SECURITY_NONE, /* The connection is neither encrypted nor verified. */
-    MIDORI_SECURITY_UNKNOWN, /* The security is unknown, due to lack of validation. */
-    MIDORI_SECURITY_TRUSTED /* The security is validated and trusted. */
-} MidoriSecurity;
-
-GType
-midori_security_get_type (void) G_GNUC_CONST;
-
-#define MIDORI_TYPE_SECURITY \
-    (midori_security_get_type ())
-
 typedef enum
 {
     MIDORI_DOWNLOAD_CANCEL,
@@ -83,9 +59,6 @@ typedef struct _MidoriViewClass           MidoriViewClass;
 GType
 midori_view_get_type                   (void) G_GNUC_CONST;
 
-GtkWidget*
-midori_view_new                        (KatzeNet*          net);
-
 GtkWidget*
 midori_view_new_with_title             (const gchar*       title,
                                         MidoriWebSettings* settings,
@@ -137,21 +110,15 @@ midori_view_has_selection              (MidoriView*        view);
 const gchar*
 midori_view_get_selected_text          (MidoriView*        view);
 
-gboolean
-midori_view_can_cut_clipboard          (MidoriView*        view);
-
-gboolean
-midori_view_can_copy_clipboard         (MidoriView*        view);
-
-gboolean
-midori_view_can_paste_clipboard        (MidoriView*        view);
-
 GtkWidget*
 midori_view_get_proxy_menu_item        (MidoriView*        view);
 
 GtkWidget*
 midori_view_get_tab_menu               (MidoriView*        view);
 
+GtkWidget*
+midori_view_duplicate                  (MidoriView*        view);
+
 PangoEllipsizeMode
 midori_view_get_label_ellipsize        (MidoriView*        view);
 
@@ -162,10 +129,10 @@ midori_view_get_tab                    (MidoriView*        view);
 void
 midori_view_set_tab                    (MidoriView*        view,
                                         GraniteWidgetsTab* tab);
-#else
+#endif
+
 GtkWidget*
 midori_view_get_proxy_tab_label        (MidoriView*        view);
-#endif
 
 KatzeItem*
 midori_view_get_proxy_item             (MidoriView*        view);
@@ -187,9 +154,6 @@ void
 midori_view_reload                     (MidoriView*        view,
                                         gboolean           from_cache);
 
-void
-midori_view_stop_loading               (MidoriView*        view);
-
 gboolean
 midori_view_can_go_back                (MidoriView*        view);
 
@@ -222,32 +186,17 @@ midori_view_print                      (MidoriView*        view);
 gboolean
 midori_view_can_view_source            (MidoriView*        view);
 
-gboolean
-midori_view_can_save                   (MidoriView*        view);
-
 gchar*
 midori_view_save_source                (MidoriView*        view,
                                         const gchar*       uri,
                                         const gchar*       outfile);
 
-void
-midori_view_unmark_text_matches        (MidoriView*        view);
-
 void
 midori_view_search_text                (MidoriView*        view,
                                         const gchar*       text,
                                         gboolean           case_sensitive,
                                         gboolean           forward);
 
-void
-midori_view_mark_text_matches          (MidoriView*        view,
-                                        const gchar*       text,
-                                        gboolean           case_sensitive);
-
-void
-midori_view_set_highlight_text_matches (MidoriView*        view,
-                                        gboolean           highlight);
-
 gboolean
 midori_view_execute_script             (MidoriView*        view,
                                         const gchar*       script,
@@ -264,9 +213,6 @@ midori_view_get_web_view               (MidoriView*        view);
 MidoriView*
 midori_view_get_for_widget             (GtkWidget*         web_view);
 
-MidoriSecurity
-midori_view_get_security               (MidoriView*        view);
-
 void
 midori_view_populate_popup             (MidoriView*        view,
                                         GtkWidget*         menu,
@@ -285,6 +231,18 @@ const gchar*
 midori_view_fallback_extension         (MidoriView*        view,
                                         const gchar*       extension);
 
+GList*
+midori_view_get_resources              (MidoriView*        view);
+
+void
+midori_view_list_versions              (GString*           markup,
+                                        gboolean           html);
+
+void
+midori_view_list_plugins               (MidoriView*        view,
+                                        GString*           markup,
+                                        gboolean           html);
+
 G_END_DECLS
 
 #endif /* __MIDORI_VIEW_H__ */
