@@ -32,18 +32,7 @@
 #include <glib/gi18n.h>
 #include <glib/gprintf.h>
 #include <glib/gstdio.h>
-#include <webkit/webkit.h>
-
-#ifdef HAVE_HILDON_FM
-    #include <hildon/hildon-file-chooser-dialog.h>
-#endif
-
-#if HAVE_HILDON
-    #include <libosso.h>
-    #include <hildon/hildon.h>
-    #include <hildon-mime.h>
-    #include <hildon-uri.h>
-#endif
+#include "katze/katze.h"
 
 static gchar*
 sokoke_js_string_utf8 (JSStringRef js_string)
@@ -109,14 +98,6 @@ sokoke_js_script_eval (JSContextRef js_context,
     return value;
 }
 
-static void
-sokoke_message_dialog_response_cb (GtkWidget* dialog,
-                                   gint       response,
-                                   gpointer   data)
-{
-    gtk_widget_destroy (dialog);
-}
-
 void
 sokoke_message_dialog (GtkMessageType message_type,
                        const gchar*   short_message,
@@ -124,13 +105,7 @@ sokoke_message_dialog (GtkMessageType message_type,
                        gboolean       modal)
 {
     GtkWidget* dialog = gtk_message_dialog_new (
-        NULL, 0, message_type,
-        #if HAVE_HILDON
-        GTK_BUTTONS_NONE,
-        #else
-        GTK_BUTTONS_OK,
-        #endif
-        "%s", short_message);
+        NULL, 0, message_type, GTK_BUTTONS_OK, "%s", short_message);
     gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
                                               "%s", detailed_message);
     if (modal)
@@ -140,90 +115,13 @@ sokoke_message_dialog (GtkMessageType message_type,
     }
     else
     {
-        g_signal_connect (dialog, "response",
-                          G_CALLBACK (sokoke_message_dialog_response_cb), NULL);
+        g_signal_connect_swapped (dialog, "response",
+            G_CALLBACK (gtk_widget_destroy), dialog);
         gtk_widget_show (dialog);
     }
 
 }
 
-/**
- * sokoke_show_uri_with_mime_type:
- * @screen: a #GdkScreen, or %NULL
- * @uri: the URI to show
- * @mime_type: a MIME type
- * @timestamp: the timestamp of the event
- * @error: the location of a #GError, or %NULL
- *
- * Shows the specified URI with an appropriate application,
- * as though it had the specified MIME type.
- *
- * On Maemo, hildon_mime_open_file_with_mime_type() is used.
- *
- * See also: sokoke_show_uri().
- *
- * Return value: %TRUE on success, %FALSE if an error occurred
- **/
-gboolean
-sokoke_show_uri_with_mime_type (GdkScreen*   screen,
-                                const gchar* uri,
-                                const gchar* mime_type,
-                                guint32      timestamp,
-                                GError**     error)
-{
-    gboolean success;
-    #if HAVE_HILDON
-    osso_context_t* osso;
-    DBusConnection* dbus;
-
-    osso = osso_initialize (PACKAGE_NAME, PACKAGE_VERSION, FALSE, NULL);
-    if (!osso)
-    {
-        g_print ("Failed to initialize libosso\n");
-        return FALSE;
-    }
-
-    dbus = (DBusConnection *) osso_get_dbus_connection (osso);
-    if (!dbus)
-    {
-        osso_deinitialize (osso);
-        g_print ("Failed to get dbus connection from osso context\n");
-        return FALSE;
-    }
-
-    success = (hildon_mime_open_file_with_mime_type (dbus,
-               uri, mime_type) == 1);
-    osso_deinitialize (osso);
-    #else
-    GFile* file = g_file_new_for_uri (uri);
-    gchar* content_type;
-    GAppInfo* app_info;
-    GList* files;
-    gpointer context;
-
-    content_type = g_content_type_from_mime_type (mime_type);
-    app_info = g_app_info_get_default_for_type (content_type,
-        !g_str_has_prefix (uri, "file://"));
-    g_free (content_type);
-    files = g_list_prepend (NULL, file);
-    #if GTK_CHECK_VERSION (3, 0, 0)
-    context = gdk_display_get_app_launch_context (gdk_screen_get_display (screen));
-    #else
-    context = gdk_app_launch_context_new ();
-    #endif
-    gdk_app_launch_context_set_screen (context, screen);
-    gdk_app_launch_context_set_timestamp (context, timestamp);
-
-    success = g_app_info_launch (app_info, files, context, error);
-
-    g_object_unref (app_info);
-    g_list_free (files);
-    g_object_unref (file);
-    #endif
-
-    return success;
-}
-
 static void
 sokoke_open_with_response_cb (GtkWidget* dialog,
                               gint       response,
@@ -233,7 +131,7 @@ sokoke_open_with_response_cb (GtkWidget* dialog,
     {
         const gchar* command = gtk_entry_get_text (entry);
         const gchar* uri = g_object_get_data (G_OBJECT (dialog), "uri");
-        sokoke_spawn_program (command, FALSE, uri, TRUE);
+        sokoke_spawn_program (command, FALSE, uri, TRUE, FALSE);
     }
     gtk_widget_destroy (dialog);
 }
@@ -246,8 +144,6 @@ sokoke_default_for_uri (const gchar* uri,
     GAppInfo* info;
 
     scheme = g_uri_parse_scheme (uri);
-    if (scheme_ptr != NULL)
-        *scheme_ptr = scheme;
     if (!scheme)
         return NULL;
 
@@ -260,7 +156,9 @@ sokoke_default_for_uri (const gchar* uri,
         g_free (type);
     }
     #endif
-    if (info != NULL && scheme_ptr != NULL)
+    if (scheme_ptr != NULL)
+        *scheme_ptr = scheme;
+    else
         g_free (scheme);
     return info;
 
@@ -273,13 +171,9 @@ sokoke_default_for_uri (const gchar* uri,
  * @timestamp: the timestamp of the event
  * @error: the location of a #GError, or %NULL
  *
- * Shows the specified URI with an appropriate application. This
- * supports xdg-open, exo-open and gnome-open as fallbacks if
- * GIO doesn't do the trick.
+ * Shows the specified URI with an application or xdg-open.
  * x-scheme-handler is supported for GLib < 2.28 as of 0.3.3.
  *
- * On Maemo, hildon_uri_open() is used.
- *
  * Return value: %TRUE on success, %FALSE if an error occurred
  **/
 gboolean
@@ -288,11 +182,7 @@ sokoke_show_uri (GdkScreen*   screen,
                  guint32      timestamp,
                  GError**     error)
 {
-    #if HAVE_HILDON
-    HildonURIAction* action = hildon_uri_get_default_action_by_uri (uri, NULL);
-    return hildon_uri_open (uri, action, error);
-
-    #elif defined (G_OS_WIN32)
+    #ifdef G_OS_WIN32
     CoInitializeEx (NULL, COINIT_APARTMENTTHREADED);
     SHELLEXECUTEINFO info = { sizeof (info) };
     info.nShow = SW_SHOWNORMAL;
@@ -305,8 +195,6 @@ sokoke_show_uri (GdkScreen*   screen,
     GAppInfo* info;
     gchar* scheme;
     #endif
-    const gchar* fallbacks [] = { "xdg-open", "exo-open", "gnome-open" };
-    gsize i;
     GtkWidget* dialog;
     GtkWidget* box;
     gchar* filename;
@@ -319,6 +207,7 @@ sokoke_show_uri (GdkScreen*   screen,
 
     sokoke_recursive_fork_protection (uri, TRUE);
 
+    /* g_app_info_launch_default_for_uri, gdk_display_get_app_launch_context */
     if (gtk_show_uri (screen, uri, timestamp, error))
         return TRUE;
 
@@ -341,9 +230,8 @@ sokoke_show_uri (GdkScreen*   screen,
     }
     #endif
 
-    for (i = 0; i < G_N_ELEMENTS (fallbacks); i++)
     {
-        gchar* command = g_strconcat (fallbacks[i], " ", uri, NULL);
+        gchar* command = g_strconcat ("xdg-open ", uri, NULL);
         gboolean result = g_spawn_command_line_async (command, error);
         g_free (command);
         if (result)
@@ -449,6 +337,7 @@ sokoke_prepare_command (const gchar* command,
  * @argument: any arguments, properly quoted
  * @quote_command: if %TRUE, @command will be quoted
  * @quote_argument: if %TRUE, @argument will be quoted, ie. a URI or filename
+ * @sync: spawn synchronously and wait for command to exit
  *
  * If @command contains %s, @argument will be quoted and inserted into
  * @command, which is left unquoted regardless of @quote_command.
@@ -459,7 +348,8 @@ gboolean
 sokoke_spawn_program (const gchar* command,
                       gboolean     quote_command,
                       const gchar* argument,
-                      gboolean     quote_argument)
+                      gboolean     quote_argument,
+                      gboolean     sync)
 {
     GError* error;
     gchar* command_ready;
@@ -484,9 +374,15 @@ sokoke_spawn_program (const gchar* command,
     g_free (command_ready);
 
     error = NULL;
-    if (!g_spawn_async (NULL, argv, NULL,
-        (GSpawnFlags)G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
-        NULL, NULL, NULL, &error))
+    if (sync)
+        g_spawn_sync (NULL, argv, NULL,
+            (GSpawnFlags)G_SPAWN_SEARCH_PATH,
+            NULL, NULL, NULL, NULL, NULL, &error);
+    else
+        g_spawn_async (NULL, argv, NULL,
+            (GSpawnFlags)G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD,
+            NULL, NULL, NULL, &error);
+    if (error != NULL)
     {
         sokoke_message_dialog (GTK_MESSAGE_ERROR,
                                _("Could not run external program."),
@@ -507,14 +403,14 @@ sokoke_spawn_app (const gchar* uri,
     gchar* argument;
     if (private)
     {
-        gchar* config_quoted = g_shell_quote (midori_paths_get_config_dir ());
+        gchar* config_quoted = g_shell_quote (midori_paths_get_config_dir_for_reading ());
         argument = g_strconcat ("-c ", config_quoted,
                                 " -p ", uri_quoted, NULL);
     }
     else
         argument = g_strconcat ("-a ", uri_quoted, NULL);
     g_free (uri_quoted);
-    sokoke_spawn_program (executable, TRUE, argument, FALSE);
+    sokoke_spawn_program (executable, TRUE, argument, FALSE, FALSE);
     g_free (argument);
 }
 
@@ -574,6 +470,25 @@ sokoke_external_uri (const gchar* uri)
     return info != NULL;
 }
 
+gchar*
+sokoke_prepare_uri (const gchar *uri)
+{
+    gchar* uri_ready;
+
+    if (g_str_has_prefix (uri, "javascript:"))
+        return g_strdup (uri);
+    else if (g_file_test (uri, G_FILE_TEST_EXISTS | G_FILE_TEST_IS_REGULAR)
+         && !g_path_is_absolute (uri))
+    {
+        GFile* file = g_file_new_for_commandline_arg (uri);
+        uri_ready = g_file_get_uri (file);
+        g_object_unref (file);
+        return uri_ready;
+    }
+
+    return sokoke_magic_uri (uri);
+}
+
 /**
  * sokoke_magic_uri:
  * @uri: a string typed by a user
@@ -869,7 +784,7 @@ sokoke_action_create_popup_menu_item (GtkAction* action)
         if (label)
         {
             menuitem = gtk_image_menu_item_new_with_mnemonic (label);
-            icon = gtk_image_new_from_stock (stock_id, GTK_ICON_SIZE_MENU);
+            icon = gtk_action_create_icon (action, GTK_ICON_SIZE_MENU);
             gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem), icon);
         }
         else
@@ -917,45 +832,6 @@ sokoke_time_t_to_julian (const time_t* timestamp)
     return julian;
 }
 
-/**
- * sokoke_remove_path:
- * @path: an absolute path
- * @ignore_errors: keep removing even if an error occurred
- *
- * Removes the file at @path or the folder including any
- * child folders and files if @path is a folder.
- *
- * If @ignore_errors is %TRUE and @path is a folder with
- * children, one of which can't be removed, remaining
- * children will be deleted nevertheless
- * If @ignore_errors is %FALSE and @path is a folder, the
- * removal process will cancel immediately.
- *
- * Return value: %TRUE on success, %FALSE if an error occurred
- **/
-gboolean
-sokoke_remove_path (const gchar* path,
-                    gboolean     ignore_errors)
-{
-    GDir* dir = g_dir_open (path, 0, NULL);
-    const gchar* name;
-
-    if (!dir)
-        return g_remove (path) == 0;
-
-    while ((name = g_dir_read_name (dir)))
-    {
-        gchar* sub_path = g_build_filename (path, name, NULL);
-        if (!sokoke_remove_path (sub_path, ignore_errors) && !ignore_errors)
-            return FALSE;
-        g_free (sub_path);
-    }
-
-    g_dir_close (dir);
-    g_rmdir (path);
-    return TRUE;
-}
-
 gchar*
 sokoke_replace_variables (const gchar* template,
                           const gchar* variable_first, ...)
@@ -1056,40 +932,6 @@ sokoke_gtk_action_count_modifiers (GtkAction* action)
     return cmods;
 }
 
-/**
- * sokoke_file_chooser_dialog_new:
- * @title: a window title, or %NULL
- * @window: a parent #GtkWindow, or %NULL
- * @action: a #GtkFileChooserAction
- *
- * Creates a new file chooser dialog, as appropriate for
- * the platform, with buttons according to the @action.
- *
- * The positive response is %GTK_RESPONSE_OK.
- *
- * Return value: a new #GtkFileChooser
- **/
-GtkWidget*
-sokoke_file_chooser_dialog_new (const gchar*         title,
-                                GtkWindow*           window,
-                                GtkFileChooserAction action)
-{
-    const gchar* stock_id = GTK_STOCK_OPEN;
-    GtkWidget* dialog;
-
-    if (action == GTK_FILE_CHOOSER_ACTION_SAVE)
-        stock_id = GTK_STOCK_SAVE;
-    #ifdef HAVE_HILDON_FM
-    dialog = hildon_file_chooser_dialog_new (window, action);
-    #else
-    dialog = gtk_file_chooser_dialog_new (title, window, action,
-        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-        stock_id, GTK_RESPONSE_OK, NULL);
-    gtk_window_set_icon_name (GTK_WINDOW (dialog), stock_id);
-    #endif
-    return dialog;
-}
-
 /**
  * sokoke_prefetch_uri:
  * @settings: a #MidoriWebSettings instance, or %NULL
@@ -1103,7 +945,11 @@ sokoke_file_chooser_dialog_new (const gchar*         title,
 gboolean
 sokoke_prefetch_uri (MidoriWebSettings*  settings,
                      const char*         uri,
+#ifndef HAVE_WEBKIT2
                      SoupAddressCallback callback,
+#else
+                     void*               callback,
+#endif
                      gpointer            user_data)
 {
     #define MAXHOSTS 50
@@ -1142,10 +988,15 @@ sokoke_prefetch_uri (MidoriWebSettings*  settings,
         new_hosts = g_strdup_printf ("%s|%s", hosts, hostname);
         katze_assign (hosts, new_hosts);
     }
+#ifndef HAVE_WEBKIT2
     else if (callback)
         callback (NULL, SOUP_STATUS_OK, user_data);
     g_free (hostname);
     return TRUE;
+#else
+    g_free (hostname);
+    return FALSE;
+#endif
 }
 
 /**
@@ -1178,40 +1029,6 @@ sokoke_recursive_fork_protection (const gchar* uri,
     return g_strcmp0 (fork_uri, uri) == 0 ? FALSE : TRUE;
 }
 
-/**
- * sokoke_register_privacy_item:
- * @name: the name of the privacy item
- * @label: a user visible, localized label
- * @clear: a callback clearing data
- *
- * Registers an item to clear data, either via the
- * Clear Private Data dialogue or when Midori quits.
- *
- * Return value: a #GList if all arguments are %NULL
- **/
-GList*
-sokoke_register_privacy_item (const gchar* name,
-                              const gchar* label,
-                              GCallback    clear)
-{
-    static GList* items = NULL;
-    SokokePrivacyItem* item;
-
-    if (name == NULL && label == NULL && clear == NULL)
-        return items;
-
-    g_return_val_if_fail (name != NULL, NULL);
-    g_return_val_if_fail (label != NULL, NULL);
-    g_return_val_if_fail (clear != NULL, NULL);
-
-    item = g_new (SokokePrivacyItem, 1);
-    item->name = g_strdup (name);
-    item->label = g_strdup (label);
-    item->clear = clear;
-    items = g_list_append (items, item);
-    return NULL;
-}
-
 static void
 sokoke_widget_clipboard_owner_clear_func (GtkClipboard* clipboard,
                                           gpointer      user_data)
