@@ -14,7 +14,7 @@
 #define __SOKOKE_H__ 1
 
 #include <JavaScriptCore/JavaScript.h>
-#include <webkit/webkit.h>
+#include "katze/katze.h"
 #include <midori/midori-websettings.h>
 #include <katze/gtk3-compat.h>
 
@@ -52,7 +52,8 @@ gboolean
 sokoke_spawn_program                    (const gchar* command,
                                          gboolean        quote_command,
                                          const gchar*    argument,
-                                         gboolean        quote_argument);
+                                         gboolean        quote_argument,
+                                         gboolean        sync);
 
 void
 sokoke_spawn_app                        (const gchar*    uri,
@@ -105,7 +106,11 @@ sokoke_gtk_action_count_modifiers       (GtkAction* action);
 gboolean
 sokoke_prefetch_uri                     (MidoriWebSettings*  settings,
                                          const char*         uri,
+#ifndef HAVE_WEBKIT2
                                          SoupAddressCallback callback,
+#else
+                                         void*               callback,
+#endif
                                          gpointer            user_data);
 
 gboolean
