@@ -658,22 +658,12 @@ midori_bookmarks_treeview_render_icon_cb (GtkTreeViewColumn* column,
 
     gtk_tree_model_get (model, iter, 0, &item, -1);
 
-    /* TODO: Would it be better to not do this on every redraw? */
-    pixbuf = NULL;
-    if (KATZE_ITEM_IS_FOLDER (item))
-        pixbuf = gtk_widget_render_icon (treeview, GTK_STOCK_DIRECTORY,
-                                         GTK_ICON_SIZE_MENU, NULL);
-    else if ((pixbuf = katze_item_get_pixbuf (item, treeview)))
-        ;
-    else if (KATZE_ITEM_IS_BOOKMARK (item))
-        pixbuf = katze_load_cached_icon (katze_item_get_uri (item), treeview);
+    pixbuf = katze_item_get_pixbuf (item, treeview);
     g_object_set (renderer, "pixbuf", pixbuf, NULL);
 
     if (pixbuf)
         g_object_unref (pixbuf);
-
-    if (item)
-        g_object_unref (item);
+    g_object_unref (item);
 }
 
 static void
@@ -782,7 +772,6 @@ midori_bookmarks_open_in_tab_activate_cb (GtkWidget*       menuitem,
 {
     KatzeItem* item;
     const gchar* uri;
-    guint n;
 
     item = (KatzeItem*)g_object_get_data (G_OBJECT (menuitem), "KatzeItem");
     if (KATZE_ITEM_IS_FOLDER (item))
@@ -798,21 +787,17 @@ midori_bookmarks_open_in_tab_activate_cb (GtkWidget*       menuitem,
         {
             if ((uri = katze_item_get_uri (child)) && *uri)
             {
-                MidoriBrowser* browser;
-
-                browser = midori_browser_get_for_widget (GTK_WIDGET (bookmarks));
-                n = midori_browser_add_item (browser, child);
-                midori_browser_set_current_page_smartly (browser, n);
+                MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (bookmarks));
+                GtkWidget* view = midori_browser_add_item (browser, child);
+                midori_browser_set_current_tab_smartly (browser, view);
             }
         }
     }
     else if ((uri = katze_item_get_uri (item)) && *uri)
     {
-        MidoriBrowser* browser;
-
-        browser = midori_browser_get_for_widget (GTK_WIDGET (bookmarks));
-        n = midori_browser_add_item (browser, item);
-        midori_browser_set_current_page_smartly (browser, n);
+        MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (bookmarks));
+        GtkWidget* view = midori_browser_add_item (browser, item);
+        midori_browser_set_current_tab_smartly (browser, view);
     }
 }
 
@@ -891,12 +876,9 @@ midori_bookmarks_button_release_event_cb (GtkWidget*       widget,
             const gchar* uri;
             if (KATZE_ITEM_IS_BOOKMARK (item) && (uri = katze_item_get_uri (item)) && *uri)
             {
-                MidoriBrowser* browser;
-                gint n;
-
-                browser = midori_browser_get_for_widget (widget);
-                n = midori_browser_add_uri (browser, uri);
-                midori_browser_set_current_page (browser, n);
+                MidoriBrowser* browser = midori_browser_get_for_widget (widget);
+                GtkWidget* view = midori_browser_add_uri (browser, uri);
+                midori_browser_set_current_tab (browser, view);
             }
         }
         else
@@ -1007,8 +989,8 @@ midori_bookmarks_filter_entry_changed_cb (GtkEntry*        entry,
     else
         katze_assign (bookmarks->filter, NULL);
 
-    bookmarks->filter_timeout = g_timeout_add (COMPLETION_DELAY,
-        midori_bookmarks_filter_timeout_cb, bookmarks);
+    bookmarks->filter_timeout = midori_timeout_add (COMPLETION_DELAY,
+        midori_bookmarks_filter_timeout_cb, bookmarks, NULL);
 }
 
 static void
