@@ -165,6 +165,8 @@ midori_history_format_date (KatzeItem *item)
         sdate = g_strdup (_("A week ago"));
     else
         sdate = g_date_time_format (then, "%x");
+    g_date_time_unref (now);
+    g_date_time_unref (then);
     #else
     gchar token[50];
     time_t current_time;
@@ -592,23 +594,12 @@ midori_history_treeview_render_icon_cb (GtkTreeViewColumn* column,
 
     gtk_tree_model_get (model, iter, 0, &item, -1);
 
-    if (!item)
-        pixbuf = NULL;
-    else if ((pixbuf = katze_item_get_pixbuf (item, treeview)))
-        ;
-    else if (katze_item_get_uri (item))
-        pixbuf = katze_load_cached_icon (katze_item_get_uri (item), treeview);
-    else
-        pixbuf = gtk_widget_render_icon (treeview, GTK_STOCK_DIRECTORY,
-                                         GTK_ICON_SIZE_MENU, NULL);
-
+    pixbuf = katze_item_get_pixbuf (item, treeview);
     g_object_set (renderer, "pixbuf", pixbuf, NULL);
 
     if (pixbuf)
-    {
         g_object_unref (pixbuf);
-        g_object_unref (item);
-    }
+    g_object_unref (item);
 }
 
 static void
@@ -750,11 +741,9 @@ midori_history_open_in_tab_activate_cb (GtkWidget*     menuitem,
         {
             if ((uri = katze_item_get_uri (child)) && *uri)
             {
-                MidoriBrowser* browser;
-
-                browser = midori_browser_get_for_widget (GTK_WIDGET (history));
-                n = midori_browser_add_item (browser, child);
-                midori_browser_set_current_page_smartly (browser, n);
+                MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (history));
+                GtkWidget* view = midori_browser_add_item (browser, child);
+                midori_browser_set_current_tab_smartly (browser, view);
             }
         }
     }
@@ -762,11 +751,9 @@ midori_history_open_in_tab_activate_cb (GtkWidget*     menuitem,
     {
         if ((uri = katze_item_get_uri (item)) && *uri)
         {
-            MidoriBrowser* browser;
-
-            browser = midori_browser_get_for_widget (GTK_WIDGET (history));
-            n = midori_browser_add_item (browser, item);
-            midori_browser_set_current_page_smartly (browser, n);
+            MidoriBrowser* browser = midori_browser_get_for_widget (GTK_WIDGET (history));
+            GtkWidget* view = midori_browser_add_item (browser, item);
+            midori_browser_set_current_tab_smartly (browser, view);
         }
     }
 }
@@ -851,12 +838,9 @@ midori_history_button_release_event_cb (GtkWidget*      widget,
 
             if (uri && *uri)
             {
-                MidoriBrowser* browser;
-                gint n;
-
-                browser = midori_browser_get_for_widget (widget);
-                n = midori_browser_add_uri (browser, uri);
-                midori_browser_set_current_page (browser, n);
+                MidoriBrowser* browser = midori_browser_get_for_widget (widget);
+                GtkWidget* view = midori_browser_add_uri (browser, uri);
+                midori_browser_set_current_tab (browser, view);
             }
         }
         else
@@ -965,8 +949,8 @@ midori_history_filter_entry_changed_cb (GtkEntry*      entry,
 {
     if (history->filter_timeout)
         g_source_remove (history->filter_timeout);
-    history->filter_timeout = g_timeout_add (COMPLETION_DELAY,
-        midori_history_filter_timeout_cb, history);
+    history->filter_timeout = midori_timeout_add (COMPLETION_DELAY,
+        midori_history_filter_timeout_cb, history, NULL);
 
     if (!g_object_get_data (G_OBJECT (entry), "sokoke_has_default"))
         katze_assign (history->filter, g_strdup (gtk_entry_get_text (entry)));
