@@ -15,16 +15,51 @@ static void
 browser_create (void)
 {
     MidoriApp* app;
-    MidoriSpeedDial* dial;
+    MidoriWebSettings* settings;
     MidoriBrowser* browser;
+    gchar* temporary_downloads;
+    gchar* temporary_filename;
+    GtkWidget* view;
+    GFile* file;
+    gchar* uri;
+    gchar* filename;
+    gchar* filename2;
 
-    app = midori_app_new ();
-    dial = midori_speed_dial_new ("/", NULL);
-    g_object_set (app, "speed-dial", dial, NULL);
+    midori_test_log_set_fatal_handler_for_icons ();
+
+    app = midori_app_new (NULL);
+    settings = midori_web_settings_new ();
+    g_object_set (app, "settings", settings, NULL);
     browser = midori_app_create_browser (app);
+    file = g_file_new_for_commandline_arg ("./data/about.css");
+    uri = g_file_get_uri (file);
+    g_object_unref (file);
+    view = midori_browser_add_uri (browser, uri);
+
+    midori_test_set_dialog_response (GTK_RESPONSE_OK);
+    temporary_downloads = midori_paths_make_tmp_dir ("saveXXXXXX");
+    temporary_filename = g_build_filename (temporary_downloads, "test.html", NULL);
+    midori_test_set_file_chooser_filename (temporary_filename);
+    midori_settings_set_download_folder (MIDORI_SETTINGS (settings), temporary_downloads);
+    midori_browser_save_uri (browser, MIDORI_VIEW (view), NULL);
+
+    filename = midori_view_save_source (MIDORI_VIEW (view), NULL, NULL);
+    filename2 = g_filename_from_uri (uri, NULL, NULL);
+    g_assert_cmpstr (filename, ==, filename2);
+    g_free (filename);
+    g_free (filename2);
+
+    /* View source for local file: should NOT use temporary file */
+    view = midori_browser_add_uri (browser, uri);
+    midori_browser_set_current_tab (browser, view);
+    g_assert_cmpstr (uri, ==, midori_browser_get_current_uri (browser));
+    g_free (uri);
+    g_free (temporary_downloads);
+    g_free (temporary_filename);
+
     gtk_widget_destroy (GTK_WIDGET (browser));
+    g_object_unref (settings);
     g_object_unref (app);
-    g_object_unref (dial);
 }
 
 static void
@@ -110,13 +145,25 @@ browser_site_data (void)
     g_object_unref (settings);
 }
 
+static void
+browser_block_uris (void)
+{
+    MidoriWebSettings* settings = g_object_new (MIDORI_TYPE_WEB_SETTINGS, NULL);
+    gchar* pattern = katze_object_get_string (settings, "block-uris");
+    g_object_set (settings, "block-uris", NULL, NULL);
+    g_object_set (settings, "block-uris", "", NULL);
+    g_object_set (settings, "block-uris", "^(?!.*?(gmail|mail\\.google|accounts\\.google)).*", NULL);
+    g_free (pattern);
+    g_object_unref (settings);
+}
+
 int
 main (int    argc,
       char** argv)
 {
     g_test_init (&argc, &argv, NULL);
-    midori_app_setup (&argc, &argv, NULL, NULL);
-    midori_paths_init (MIDORI_RUNTIME_MODE_PRIVATE, NULL);
+    midori_app_setup (&argc, &argv, NULL);
+    midori_paths_init (MIDORI_RUNTIME_MODE_NORMAL, NULL);
 
     g_object_set_data (G_OBJECT (webkit_get_default_session ()),
                        "midori-session-initialized", (void*)1);
@@ -124,6 +171,7 @@ main (int    argc,
     g_test_add_func ("/browser/create", browser_create);
     g_test_add_func ("/browser/tooltips", browser_tooltips);
     g_test_add_func ("/browser/site_data", browser_site_data);
+    g_test_add_func ("/browser/block_uris", browser_block_uris);
 
     return g_test_run ();
 }
