@@ -63,6 +63,7 @@ properties_type_test (gconstpointer type)
 {
     GObject* object;
 
+    midori_test_log_set_fatal_handler_for_icons ();
     object = g_object_new ((GType)type, NULL);
     properties_object_test ((gconstpointer)object);
 }
@@ -83,7 +84,7 @@ main (int    argc,
       char** argv)
 {
     g_test_init (&argc, &argv, NULL);
-    midori_app_setup (&argc, &argv, NULL, NULL);
+    midori_app_setup (&argc, &argv, NULL);
     midori_paths_init (MIDORI_RUNTIME_MODE_PRIVATE, NULL);
 
     g_object_set_data (G_OBJECT (webkit_get_default_session ()),
